@@ -294,7 +294,7 @@ class CustomResourceProvider:
             def stub(
                 *,
                 api_version: builtins.str,
-                handler: "ICustomResourceProviderHandler",
+                handler: ICustomResourceProviderHandler,
                 kind: builtins.str,
             ) -> None:
                 ...
